yakumo.neutron.v2.port

Package yakumo :: Package neutron :: Package v2 :: Module port |
[hide private]
[frames] | no frames]

# Module port

source code

Resource class and its manager for ports in Networking V2 API

Classes | [hide private]
| Resource Resource class for ports in Networking V2 API
| Manager Manager class for ports in Networking V2 API

Variables | [hide private]
| FIXED_IP_MAPPING = ``[``(``'``ip_address``'``,` `'``ip_address``'``,` <yakumo.mappe`...``
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### FIXED_IP_MAPPING Value:
      [('ip_address', 'ip_address', mapper.Noop), ('subnet', 'subnet_id', ma
      pper.Resource('neutron.subnet')),]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('network', 'network_id', mapper.Resource('neu
      tron.network')), ('project', 'tenant_id', mapper.Resource('project')),
       ('device', 'device_id', mapper.Noop), ('device_owner', 'device_owner'
      , mapper.Noop), ('allowed_address_pairs', 'allowed_address_pairs', map
      per.Noop), ('mac_address', 'mac_address', mapper.Noop), ('fixed_ips',
      'fixed_ips', mapper.List(mapper.Dict(FIXED_IP_MAPPING))), ('security_g
      roups', 'security_groups', mapper.Noop), ('is_enabled', 'admin_state_u
      ...